#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_NEGATE_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_NEGATE_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/negate.hpp>

#endif
